Index: net/url_request/url_request_error_job.h |
diff --git a/net/url_request/url_request_error_job.h b/net/url_request/url_request_error_job.h |
index 6e7c8793c7c0934a351cc20fab3987be0e483faf..58729c8c6e9733d37388ba3f13cd44d55222541d 100644 |
--- a/net/url_request/url_request_error_job.h |
+++ b/net/url_request/url_request_error_job.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
// |
// Invalid URLs go through this URLRequestJob class rather than being passed |
// to the default job handler. |
#ifndef NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_ |
#define NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_ |
@@ -11,7 +11,7 @@ |
#include "net/url_request/url_request_job.h" |
-class URLRequestErrorJob : public URLRequestJob { |
+class URLRequestErrorJob : public net::URLRequestJob { |
public: |
URLRequestErrorJob(net::URLRequest* request, int error); |
@@ -2,8 +2,8 @@ |
// found in the LICENSE file. |
// |
-// Invalid URLs go through this URLRequestJob class rather than being passed |
-// to the default job handler. |
+// Invalid URLs go through this net::URLRequestJob class rather than being |
+// passed to the default job handler. |
#ifndef NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_ |
#define NET_URL_REQUEST_URL_REQUEST_ERROR_JOB_H_ |